// import React, { useState } from 'react';
// import axios from 'axios';

// function Signup() {
//   const [form, setForm] = useState({ username: '', email: '', password: '' });
//   const [error, setError] = useState('');

//   const handleChange = (e) => setForm({ ...form, [e.target.name]: e.target.value });

//   const handleSubmit = async (e) => {
//     e.preventDefault();
//     try {
//       await axios.post('http://localhost:5000/api/auth/register', form);
//       alert('Registration successful');
//     } catch (err) {
//       setError(err.response?.data?.error || 'Registration failed');
//     }
//   };

//   return (
//     <div>
//       <h2>Signup</h2>
//       {error && <p>{error}</p>}
//       <form onSubmit={handleSubmit}>
//         <input name="username" placeholder="Username" onChange={handleChange} required />
//         <input name="email" type="email" placeholder="Email" onChange={handleChange} required />
//         <input name="password" type="password" placeholder="Password" onChange={handleChange} required />
//         <button type="submit">Signup</button>
//       </form>
//     </div>
//   );
// }

// export default Signup;

import React, { useState } from "react";
import axios from "axios";
import { useNavigate } from "react-router-dom";

function Signup() {
  const [form, setForm] = useState({ username: "", email: "", password: "" });
  const [error, setError] = useState("");
  const [success, setSuccess] = useState(false); // track signup success
  const [loading, setLoading] = useState(false);

  const navigate = useNavigate();

  const handleChange = (e) => {
    setForm({ ...form, [e.target.name]: e.target.value });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setLoading(true);
    setError("");
    try {
      await axios.post("http://localhost:5000/api/auth/register", form);
      setSuccess(true);
    } catch (err) {
      console.error("Registration error:", err);
      setError(err.response?.data?.error || "Registration failed");
    } finally {
      setLoading(false);
    }
  };

  return (
    <div>
      <h2 className="headingText">Signup</h2>
      {error && <p style={{ color: "red" }}>{error}</p>}
      {success ? (
        <>
          <div className="centerText">
            <p style={{ color: "green" }}>Registration successful!</p>
            <button onClick={() => navigate("/login")}>Go to Login</button>
          </div>
        </>
      ) : (
        <>
          <div className="signup-form">
            <form onSubmit={handleSubmit} className="formClass">
              <input
                name="username"
                placeholder="Username"
                value={form.username}
                onChange={handleChange}
                required
              />
              <input
                name="email"
                type="email"
                placeholder="Email"
                value={form.email}
                onChange={handleChange}
                required
              />
              <input
                name="password"
                type="password"
                placeholder="Password"
                value={form.password}
                onChange={handleChange}
                required
              />
              <button type="submit" disabled={loading}>
                {loading ? "Registering..." : "Signup"}
              </button>
              <button onClick={() => navigate("/login")}>Login</button>
            </form>
          </div>
        </>
      )}
    </div>
  );
}

export default Signup;
